=== modified file 'drizzled/lex_string.h'
--- drizzled/lex_string.h	2011-01-13 02:08:31 +0000
+++ drizzled/lex_string.h	2011-01-26 02:01:07 +0000
@@ -36,6 +36,14 @@
   size_t length;
 } LEX_STRING;
 
+inline const LEX_STRING &null_lex_string()
+{
+  static LEX_STRING tmp= { NULL, 0 };
+  return tmp;
+}
+
+#define NULL_LEX_STRING null_lex_string()
+
 struct execute_string_t : public lex_string_t
 {
 private:

=== modified file 'drizzled/parser.cc'
--- drizzled/parser.cc	2011-01-26 00:17:02 +0000
+++ drizzled/parser.cc	2011-01-26 02:01:07 +0000
@@ -363,5 +363,26 @@
   return true;
 }
 
+Item *buildIdent(Session *session,
+                 const LEX_STRING &schema_name,
+                 const LEX_STRING &table_name,
+                 const LEX_STRING &field_name)
+{
+  Select_Lex *sel= session->getLex()->current_select;
+
+  if (sel->no_table_names_allowed)
+  {
+    my_error(ER_TABLENAME_NOT_ALLOWED_HERE,
+             MYF(0), table_name.str, session->where);
+  }
+
+  Item *item= (sel->parsing_place != IN_HAVING or
+               sel->get_in_sum_expr() > 0) ?
+    (Item*) new Item_field(session->getLex()->current_context(), schema_name.str, table_name.str, field_name.str) :
+    (Item*) new Item_ref(session->getLex()->current_context(), schema_name.str, table_name.str, field_name.str);
+
+  return item;
+}
+
 } // namespace parser
 } // namespace drizzled

=== modified file 'drizzled/parser.h'
--- drizzled/parser.h	2011-01-26 00:17:02 +0000
+++ drizzled/parser.h	2011-01-26 02:01:07 +0000
@@ -142,6 +142,8 @@
 bool checkFieldIdent(Session *session, const LEX_STRING &schema_name, const LEX_STRING &table_name);
 bool checkFieldIdent(Session *session, const LEX_STRING &table_name);
 
+Item *buildIdent(Session *session, const LEX_STRING &schema_name, const LEX_STRING &table_name, const LEX_STRING &field_name);
+
 } // namespace parser
 } // namespace drizzled
 

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-01-26 00:17:02 +0000
+++ drizzled/sql_yacc.yy	2011-01-26 02:01:07 +0000
@@ -5079,47 +5079,15 @@
 simple_ident_q:
           ident '.' ident
           {
-            {
-              Select_Lex *sel= Lex->current_select;
-              if (sel->no_table_names_allowed)
-              {
-                my_error(ER_TABLENAME_NOT_ALLOWED_HERE,
-                         MYF(0), $1.str, YYSession->where);
-              }
-              $$= (sel->parsing_place != IN_HAVING ||
-                  sel->get_in_sum_expr() > 0) ?
-                  (Item*) new Item_field(Lex->current_context(),
-                                         (const char *)NULL, $1.str, $3.str) :
-                  (Item*) new Item_ref(Lex->current_context(),
-                                       (const char *)NULL, $1.str, $3.str);
-            }
+            $$= parser::buildIdent(YYSession, NULL_LEX_STRING, $1, $3);
           }
         | '.' ident '.' ident
           {
-            Select_Lex *sel= Lex->current_select;
-            if (sel->no_table_names_allowed)
-            {
-              my_error(ER_TABLENAME_NOT_ALLOWED_HERE,
-                       MYF(0), $2.str, YYSession->where);
-            }
-            $$= (sel->parsing_place != IN_HAVING ||
-                sel->get_in_sum_expr() > 0) ?
-                (Item*) new Item_field(Lex->current_context(), NULL, $2.str, $4.str) :
-                (Item*) new Item_ref(Lex->current_context(),
-                                     (const char *)NULL, $2.str, $4.str);
+            $$= parser::buildIdent(YYSession, NULL_LEX_STRING, $2, $4);
           }
         | ident '.' ident '.' ident
           {
-            Select_Lex *sel= Lex->current_select;
-            if (sel->no_table_names_allowed)
-            {
-              my_error(ER_TABLENAME_NOT_ALLOWED_HERE,
-                       MYF(0), $3.str, YYSession->where);
-            }
-            $$= (sel->parsing_place != IN_HAVING ||
-                sel->get_in_sum_expr() > 0) ?
-                (Item*) new Item_field(Lex->current_context(), $1.str, $3.str, $5.str) :
-                (Item*) new Item_ref(Lex->current_context(), $1.str, $3.str, $5.str);
+            $$= parser::buildIdent(YYSession, $1, $3, $5);
           }
         ;
 

